@@ -15,7 +15,7 @@ use Path::Class;
 use File::chdir;
 use Group::Git::Repo;
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.1.0');
 our $AUTOLOAD;
 
 has conf => (
@@ -83,9 +83,9 @@ sub cmd {
     return unless -d $project;
 
     local $CWD = $project;
-    system 'git', $command, @ARGV;
+    my $cmd = join ' ', 'git', $command, @ARGV;
 
-    return;
+    return `$cmd`;
 }
 
 sub AUTOLOAD {
@@ -115,7 +115,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.0.5.
+This documentation refers to Group::Git version 0.1.0.
 
 =head1 SYNOPSIS
 
