@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use File::chdir;
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.1.0');
 
 requires 'repos';
 requires 'verbose';
@@ -33,12 +33,11 @@ sub branch {
         if ( @ARGV ) {
             my $out = `$cmd`;
             if ( $out !~ /^\s*$/xms ) {
-                print "$name\n$out";
+                return $out;
             }
         }
         else {
-            print "$name\n";
-            system $cmd if !$self->test;
+            return `$cmd` if !$self->test;
         }
     }
 
@@ -55,7 +54,7 @@ Group::Git::Cmd::Branch - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Branch version 0.0.5.
+This documentation refers to Group::Git::Cmd::Branch version 0.1.0.
 
 
 =head1 SYNOPSIS
