@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use File::chdir;
 
-our $VERSION     = version->new('0.0.5');
+our $VERSION     = version->new('0.1.0');
 
 requires 'repos';
 
@@ -23,16 +23,20 @@ sub pull {
     $type ||= 'pull';
 
     my $repo = $self->repos->{$name};
+    my $cmd;
+    my $dir;
 
     if ( -d $name ) {
-        local $CWD = $name;
-        system 'git', $type, $repo->git;
+        $dir = $name;
+        $cmd = join ' ', 'git', $type, @ARGV;
     }
     else {
-        system 'git', 'clone', $repo->git;
+        $cmd = join ' ', 'git', 'clone', $repo->git;
     }
 
-    return;
+    local $CWD = $dir if $dir;
+    warn "$cmd\n" if $self->verbose > 1;
+    return `$cmd`;
 }
 
 1;
@@ -45,7 +49,7 @@ Group::Git::Cmd::Pull - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Pull version 0.0.5.
+This documentation refers to Group::Git::Cmd::Pull version 0.1.0.
 
 
 =head1 SYNOPSIS
